PredicateTool

Struct PredicateTool 

pub struct PredicateTool { /* private fields */ }
Typed, shell-free client for one CQ-SAT/GCC executable.

Implementations

Source

impl PredicateTool

pub fn discover( executable: impl Into<PathBuf>, ) -> Result<Self, PredicateApiError>

Discover and validate the executable’s predicate CLI contract.

pub fn discover_with_policy( executable: impl Into<PathBuf>, policy: ExecutionPolicy, ) -> Result<Self, PredicateApiError>

Discover with explicit runtime bounds for discovery and later jobs.

pub fn discover_observed( executable: impl Into<PathBuf>, policy: ExecutionPolicy, ) -> Result<Observed<Self>, PredicateOperationError>

pub fn executable(&self) -> &Path

pub fn capabilities(&self) -> &PredicateCapabilities

pub fn execution_policy(&self) -> ExecutionPolicy

pub fn with_execution_policy(self, policy: ExecutionPolicy) -> Self

Return a handle with different validated bounds and unchanged capabilities.

pub fn certify( &self, version: CertificateVersion, model: &Path, bad_output: usize, transcript: &Path, certificate: &Path, ) -> Result<PredicateResult, PredicateApiError>

Produce a deterministic certificate without overwriting certificate.

pub fn certify_observed( &self, version: CertificateVersion, model: &Path, bad_output: usize, transcript: &Path, certificate: &Path, ) -> Result<Observed<PredicateResult>, PredicateOperationError>

pub fn verify( &self, version: CertificateVersion, model: &Path, certificate: &Path, ) -> Result<PredicateResult, PredicateApiError>

Verify a certificate against the selected model and return its result.

pub fn verify_observed( &self, version: CertificateVersion, model: &Path, certificate: &Path, ) -> Result<Observed<PredicateResult>, PredicateOperationError>